"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQSHelper = void 0;
const SQS = require("@aws-sdk/client-sqs");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class SQSHelper extends typescript_helper_functions_1.BaseClass {
    Repository;
    Options;
    constructor(logger, repository, options) {
        super(logger);
        this.Options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            :
                options;
        this.Repository = repository || new SQS.SQS(this.Options);
    }
    async CreateQueueAsync(queueName, attributes) {
        const action = `${SQSHelper.name}.${this.CreateQueueAsync.name}`;
        this.LogHelper.LogInputs(action, { queueName, attributes });
        if (this.ObjectOperations.IsNullOrWhitespace(queueName)) {
            throw new Error(`[${action}]-Must supply queueName`);
        }
        const params = {
            Attributes: attributes,
            QueueName: queueName,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.createQueue(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async DeleteMessageAsync(queueUrl, receiptHandle) {
        const action = `${SQSHelper.name}.${this.DeleteMessageAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl, receiptHandle });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(receiptHandle)) {
            throw new Error(`[${action}]-Must supply receiptHandle`);
        }
        const params = {
            QueueUrl: queueUrl,
            ReceiptHandle: receiptHandle,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.deleteMessage(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async DeleteMessagesAsync(queueUrl, receiptHandles) {
        const action = `${SQSHelper.name}.${this.DeleteMessagesAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl, receiptHandles });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        if (!receiptHandles || receiptHandles.length === 0) {
            throw new Error(`[${action}]-Must supply at least one receiptHandle`);
        }
        if (receiptHandles.length > 10) {
            throw new Error(`[${action}]-Can only supply up to 10 receiptHandles`);
        }
        const entries = [];
        for (const handle of receiptHandles) {
            entries.push({ Id: handle, ReceiptHandle: handle });
        }
        const params = {
            Entries: entries,
            QueueUrl: queueUrl,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.deleteMessageBatch(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async DeleteQueueAsync(queueUrl) {
        const action = `${SQSHelper.name}.${this.DeleteQueueAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        const params = {
            QueueUrl: queueUrl,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.deleteQueue(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async GetNumberOfMessagesOnQueueAsync(queueUrl) {
        const action = `${SQSHelper.name}.${this.GetNumberOfMessagesOnQueueAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        const params = {
            QueueUrl: queueUrl,
            AttributeNames: ['ApproximateNumberOfMessages'],
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.getQueueAttributes(params);
        this.LogHelper.LogResponse(action, response);
        let messages = '';
        if (response && response.Attributes) {
            messages = response.Attributes.ApproximateNumberOfMessages;
        }
        return parseInt(messages, 10);
    }
    async GetQueueAttributesAsync(queueUrl) {
        const action = `${SQSHelper.name}.${this.GetQueueAttributesAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        const params = {
            QueueUrl: queueUrl,
            AttributeNames: ['ALL'],
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.getQueueAttributes(params);
        this.LogHelper.LogResponse(action, response);
        return response.Attributes || {};
    }
    async PurgeQueueAsync(queueUrl) {
        const action = `${SQSHelper.name}.${this.PurgeQueueAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        const params = {
            QueueUrl: queueUrl,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.purgeQueue(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async ReceiveAllMessagesAsync(queueUrl, visibilityTimeout, attributeNames, messageAttributeNames) {
        let allMessages = [];
        while (true) {
            const messages = await this.ReceiveMessagesAsync(queueUrl, 10, visibilityTimeout, attributeNames, messageAttributeNames);
            if (!messages || !messages.Messages || messages.Messages.length < 1) {
                break;
            }
            allMessages = allMessages.concat(messages.Messages);
        }
        return allMessages;
    }
    async ReceiveMessagesAsync(queueUrl, maxNumberOfMessages, visibilityTimeout, attributeNames, messageAttributeNames) {
        const action = `${SQSHelper.name}.${this.ReceiveMessagesAsync.name}`;
        this.LogHelper.LogInputs(action, {
            queueUrl,
            maxNumberOfMessages,
            visibilityTimeout,
            attributeNames,
            messageAttributeNames,
        });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        if (!maxNumberOfMessages) {
            maxNumberOfMessages = 10;
        }
        if (!visibilityTimeout) {
            visibilityTimeout = 10;
        }
        if (!attributeNames || attributeNames.length === 0) {
            attributeNames = ['ALL'];
        }
        const params = {
            AttributeNames: attributeNames,
            MaxNumberOfMessages: maxNumberOfMessages,
            MessageAttributeNames: messageAttributeNames,
            QueueUrl: queueUrl,
            VisibilityTimeout: visibilityTimeout,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.receiveMessage(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async SendMessageAsync(queueUrl, messageBody, delaySeconds, messageAttributes) {
        const action = `${SQSHelper.name}.${this.SendMessageAsync.name}`;
        this.LogHelper.LogInputs(action, {
            queueUrl,
            messageBody,
            delaySeconds,
            messageAttributes,
        });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(messageBody)) {
            throw new Error(`[${action}]-Must supply messageBody`);
        }
        if (!delaySeconds) {
            delaySeconds = 0;
        }
        const params = {
            DelaySeconds: delaySeconds,
            MessageAttributes: messageAttributes,
            MessageBody: messageBody,
            QueueUrl: queueUrl,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.sendMessage(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async SendMessagesAsync(queueUrl, entries) {
        const action = `${SQSHelper.name}.${this.SendMessagesAsync.name}`;
        this.LogHelper.LogInputs(action, { queueUrl });
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        if (!entries || entries.length === 0) {
            throw new Error(`[${action}]-Must supply at least one entry`);
        }
        const params = {
            Entries: entries,
            QueueUrl: queueUrl,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.sendMessageBatch(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
}
exports.SQSHelper = SQSHelper;
//# sourceMappingURL=helper.js.map